Creates an interactive plot using ggiraph. This function extends
gf_histogram() with interactive features like tooltips and clickable elements.
gf_histogram_interactive(
object = NULL,
gformula = NULL,
data = NULL,
...,
bins,
binwidth,
alpha = 0.5,
color,
fill,
group,
linetype,
linewidth,
xlab,
ylab,
title,
subtitle,
caption,
stat = "bin",
position = "stack",
show.legend = NA,
show.help = NULL,
inherit = TRUE,
environment = parent.frame()
)A gg object that can be displayed with gf_girafe().
When chaining, this holds an object produced in the earlier portions of the chain. Most users can safely ignore this argument. See details and examples.
A formula with shape ~ x (or y ~ x, but
this shape is not generally needed).
The data to be displayed in this layer. There are three
options: If NULL, the default, the data is inherited from the
plot data as specified in the call to
ggplot(). A data.frame, or other
object, will override the plot data. All objects will be fortified to
produce a data frame. See fortify() for
which variables will be created. A function will be called with
a single argument, the plot data. The return value must be a
data.frame, and will be used as the layer data. A
function can be created from a formula (e.g. ~
head(.x, 10)).
Additional arguments passed to the underlying interactive
geom. This is where ggiraph's interactive aesthetics are supplied,
including tooltip (text shown on hover), data_id
(identifiers used for interactive selection), and onclick
(JavaScript run on click).
Number of bins. Overridden by binwidth. Defaults to
30.
The width of the bins. Can be specified as a numeric
value or as a function that takes x after scale transformation as
input and returns a single numeric value. When specifying a function
along with a grouping structure, the function will be called once per
group. The default is to use the number of bins in bins,
covering the range of the data. You should always override this value,
exploring multiple widths to find the best to illustrate the stories
in your data. The bin width of a date variable is the number of days
in each time; the bin width of a time variable is the number of
seconds.
Opacity (0 = invisible, 1 = opaque).
A color or a formula used for mapping color.
A color for filling, or a formula used for mapping fill.
Used for grouping.
A linetype (numeric or "dashed", "dotted", etc.) or a formula used for mapping linetype.
A numerical line width or a formula used for mapping linewidth.
Label for x-axis. See also
gf_labs().
Label for y-axis. See also
gf_labs().
Title, sub-title, and caption for the plot. See also
gf_labs().
Title, sub-title, and caption for the plot. See also
gf_labs().
Title, sub-title, and caption for the plot. See also
gf_labs().
Use to override the default connection between
geom_histogram()/geom_freqpoly() and stat_bin().
For more information at overriding these connections, see how the
stat and geom
arguments work.
A position adjustment to use on the data for this layer.
This can be used in various ways, including to prevent overplotting
and improving the display. The position argument accepts the
following:
The result of calling a position function,
such as position_jitter(). This method allows for passing extra
arguments to the position.
A string naming the position
adjustment. To give the position as a string, strip the function name
of the position_ prefix. For example, to use
position_jitter(), give the position as "jitter".
For more information and other ways to specify the position, see the layer position documentation.
logical. Should this layer be included in the
legends? NA, the default, includes if any aesthetics are
mapped. FALSE never includes, and TRUE always includes.
It can also be a named logical vector to finely select the aesthetics
to display. To include legend keys for all levels, even when no data
exists, use TRUE. If NA, all levels are shown in legend,
but unobserved levels are omitted.
If TRUE, display some minimal help.
A logical indicating whether default attributes are inherited.
An environment in which to look for variables not
found in data.
onclick: JavaScript code (as character string) executed when clicking elements.
Additional ggiraph aesthetics may be available depending on the geom.
gf_histogram(), gf_girafe()
# Interactive histogram with bin information
mtcars |>
gf_histogram_interactive(
~ mpg,
tooltip = ~ paste0('Min: ', round(after_stat(xmin), 1),
'; Max: ', round(after_stat(xmax),1),
'; Count: ', after_stat(count)),
bins = 15) |>
gf_girafe()
Run the code above in your browser using DataLab