- object
When chaining, this holds an object produced in the
earlier portions of the chain. Most users can safely ignore this
argument. See details and examples.
- gformula
A formula with shape y ~ x. Faceting can be
achieved by including | in the formula.
- data
A data frame with the variables to be plotted.
- ...
Additional arguments passed to the underlying interactive
geom. This is where ggiraph's interactive aesthetics are supplied,
including tooltip (text shown on hover), data_id
(identifiers used for interactive selection), and onclick
(JavaScript run on click).
- alpha
Opacity (0 = invisible, 1 = opaque).
- color
A color or a formula used for mapping color.
- fill
A color for filling, or a formula used for mapping fill.
- group
Used for grouping.
- linetype
A linetype (numeric or "dashed", "dotted", etc.) or a
formula used for mapping linetype.
- linewidth
A numerical line width or a formula used for mapping
linewidth.
- lineend
Line end style (round, butt, square).
- linejoin
Line join style (round, mitre, bevel).
- linemitre
Line mitre limit (number greater than 1).
- arrow
Arrow specification, as created by
grid::arrow().
- xlab
Label for x-axis. See also
gf_labs().
- ylab
Label for y-axis. See also
gf_labs().
- title
Title, sub-title, and caption for the plot. See also
gf_labs().
- subtitle
Title, sub-title, and caption for the plot. See also
gf_labs().
- caption
Title, sub-title, and caption for the plot. See also
gf_labs().
- stat
A character string naming the stat used to make the layer.
- position
Either a character string naming the position function
used for the layer or a position object returned from a call to a
position function.
- show.legend
A logical indicating whether this layer should be
included in the legends. NA, the default, includes layer in the
legends if any of the attributes of the layer are mapped.
- show.help
If TRUE, display some minimal help.
- inherit
A logical indicating whether default attributes are
inherited.
- environment
An environment in which to look for variables not
found in data.