Learn R Programming

ggformula (version 2.0.0)

gf_linerange_interactive: Interactive linerange plots

Description

Creates an interactive plot using ggiraph. This function extends gf_linerange() with interactive features like tooltips and clickable elements.

Usage

gf_linerange_interactive(
  object = NULL,
  gformula = NULL,
  data = NULL,
  ...,
  alpha,
  color,
  group,
  linetype,
  linewidth,
  xlab,
  ylab,
  title,
  subtitle,
  caption,
  stat = "identity",
  position = "identity",
  show.legend = NA,
  show.help = NULL,
  inherit = TRUE,
  environment = parent.frame()
)

Value

A gg object that can be displayed with gf_girafe().

Arguments

object

When chaining, this holds an object produced in the earlier portions of the chain. Most users can safely ignore this argument. See details and examples.

gformula

A formula with shape ymin + ymax ~ x. Faceting can be achieved by including | in the formula.

data

The data to be displayed in this layer. There are three options: If NULL, the default, the data is inherited from the plot data as specified in the call to ggplot(). A data.frame, or other object, will override the plot data. All objects will be fortified to produce a data frame. See fortify() for which variables will be created. A function will be called with a single argument, the plot data. The return value must be a data.frame, and will be used as the layer data. A function can be created from a formula (e.g. ~ head(.x, 10)).

...

Additional arguments passed to the underlying interactive geom. This is where ggiraph's interactive aesthetics are supplied, including tooltip (text shown on hover), data_id (identifiers used for interactive selection), and onclick (JavaScript run on click).

alpha

Opacity (0 = invisible, 1 = opaque).

color

Set or map color.

group

Use to set or map group.

linetype

Set or map style of the line.

linewidth

Set or map style of the line.

xlab

Label for x-axis. See also gf_labs().

ylab

Label for y-axis. See also gf_labs().

title

Title, sub-title, and caption for the plot. See also gf_labs().

subtitle

Title, sub-title, and caption for the plot. See also gf_labs().

caption

Title, sub-title, and caption for the plot. See also gf_labs().

stat

The statistical transformation to use on the data for this layer. When using a geom_*() function to construct a layer, the stat argument can be used to override the default coupling between geoms and stats. The stat argument accepts the following:

  • A Stat ggproto subclass, for example StatCount.

  • A string naming the stat. To give the stat as a string, strip the function name of the stat_ prefix. For example, to use stat_count(), give the stat as "count".

  • For more information and other ways to specify the stat, see the layer stat documentation.

position

A position adjustment to use on the data for this layer. This can be used in various ways, including to prevent overplotting and improving the display. The position argument accepts the following:

  • The result of calling a position function, such as position_jitter(). This method allows for passing extra arguments to the position.

  • A string naming the position adjustment. To give the position as a string, strip the function name of the position_ prefix. For example, to use position_jitter(), give the position as "jitter".

  • For more information and other ways to specify the position, see the layer position documentation.

show.legend

logical. Should this layer be included in the legends? NA, the default, includes if any aesthetics are mapped. FALSE never includes, and TRUE always includes. It can also be a named logical vector to finely select the aesthetics to display. To include legend keys for all levels, even when no data exists, use TRUE. If NA, all levels are shown in legend, but unobserved levels are omitted.

show.help

If TRUE, display some minimal help.

inherit

A logical indicating whether default attributes are inherited.

environment

An environment in which to look for variables not found in data.

Additional interactive features

  • onclick: JavaScript code (as character string) executed when clicking elements.

  • Additional ggiraph aesthetics may be available depending on the geom.

See Also

gf_linerange(), gf_girafe()

Examples

Run this code
diamonds |>
  dplyr::filter(carat < 1.1, carat > 0.9) |>
  dplyr::group_by(color, cut) |>
  dplyr::summarise(
    median_price = median(price) |> round(),
    lower = quantile(price, 0.25) |> round(),
    upper = quantile(price, 0.75) |> round(),
    iqr = upper - lower
  ) |>
  gf_linerange_interactive(
    cut ~ lower + upper | color,
    color = ~ cut,
    tooltip = ~ paste0(
      "75th percentile: ", upper,
      "\nmedian: ", median_price,
      "\n25th percentile: ", lower
      )
  ) |>
  gf_girafe()

Run the code above in your browser using DataLab